@@ -59,3 +59,54 @@ def fis_light_theme():
     rcParams['axes.prop_cycle'] = cycler(color=dark_theme_colors)
     rcParams['grid.color'] = light_white
     rcParams['image.cmap'] = 'inferno'
+
+def fis_business_theme():
+    dark_blue =  "#152238"
+    cadet_blue = "#364D6E"
+    white =      "#FFFFFF"
+    light_blue = "#DAE3F3"
+    silver =     "#D6D7D9"
+    business_colors = ["#D6D7D9","#D6D7D9","#D6D7D9","#D6D7D9",
+                       "#D6D7D9","#D6D7D9","#D6D7D9","#D6D7D9",
+                       "#D6D7D9","#D6D7D9","#D6D7D9","#D6D7D9",
+                      ]
+    sns.set(rc={
+        'text.color':dark_blue,
+        'axes.labelcolor':dark_blue,
+        'xtick.color':dark_blue,
+        'ytick.color':dark_blue,
+        'axes.spines.left':False,
+        'ytick.left': False,
+    })
+
+    sns.set_palette(business_colors)
+
+    rcParams['figure.figsize'] = 14,8
+    rcParams['axes.edgecolor'] = dark_blue
+    rcParams['axes.facecolor'] = white
+    rcParams['axes.grid'] = False
+    rcParams['axes.spines.top'] = False
+    rcParams['axes.spines.right'] = False
+    rcParams['axes.spines.left'] = False
+    rcParams['ytick.labelleft'] = True
+    rcParams['date.autoformatter.month'] = '%m/%Y'
+    rcParams['grid.alpha'] = .5
+    rcParams['axes.prop_cycle'] = cycler(color=business_colors)
+    rcParams['grid.color'] = white
+    rcParams['image.cmap'] = 'Greys'
+
+def fis_bs_histogram(df,value,labelx=None,labely=None):
+    sns.histplot(df,x=value,shrink=0.8)
+    xlocs, xlabs = plt.xticks()
+    j = 0
+    for i,v in zip(df[value].value_counts(sort=False).index,df[value].value_counts(sort=False)):
+        plt.text(xlocs[j], v+2, int(v), ha='center', fontsize=12)
+        j+=1
+
+    if labelx is not None:
+        plt.xlabel(labelx, c="#364D6E", fontsize=14)
+    if labely is not None:
+        plt.ylabel(labely, c="#364D6E", fontsize=14)
+    # remove y ticks
+    plt.yticks([])
+    plt.show()
